@@ -3,7 +3,7 @@ package CGI::Cookie;
 use strict;
 use warnings;
 
-our $VERSION='4.53';
+our $VERSION='4.56';
 
 use CGI::Util qw(rearrange unescape escape);
 use overload '""' => \&as_string, 'cmp' => \&compare, 'fallback' => 1;
@@ -104,13 +104,14 @@ sub new {
   # Ignore mod_perl request object--compatibility with Apache::Cookie.
   shift if ref $params[0]
         && eval { $params[0]->isa('Apache::Request::Req') || $params[0]->isa('Apache') };
-  my ( $name, $value, $path, $domain, $secure, $expires, $max_age, $httponly, $samesite )
+  my ( $name, $value, $path, $domain, $secure, $expires, $max_age, $httponly, $samesite, $priority )
    = rearrange(
     [
       'NAME', [ 'VALUE', 'VALUES' ],
       'PATH',   'DOMAIN',
       'SECURE', 'EXPIRES',
-      'MAX-AGE','HTTPONLY','SAMESITE'
+      'MAX-AGE','HTTPONLY','SAMESITE',
+      'PRIORITY',
     ],
     @params
    );
@@ -127,6 +128,7 @@ sub new {
   $self->max_age( $max_age )   if defined $max_age;
   $self->httponly( $httponly ) if defined $httponly;
   $self->samesite( $samesite ) if defined $samesite;
+  $self->priority( $priority ) if defined $priority;
   return $self;
 }
 
@@ -147,6 +149,7 @@ sub as_string {
     push @cookie,"secure"                    if $self->secure;
     push @cookie,"HttpOnly"                  if $self->httponly;
     push @cookie,"SameSite=".$self->samesite if $self->samesite;
+    push @cookie,"Priority=".$self->priority if $self->priority;
 
     return join "; ", @cookie;
 }
@@ -236,6 +239,16 @@ sub samesite { # SameSite
     return $self->{'samesite'};
 }
 
+my %_legal_priority = ( Low => 1, Medium => 1, High => 1 );
+sub priority {
+    my $self = shift;
+    my $priority = ucfirst lc +shift if @_;
+    if ($priority && $_legal_priority{$priority}) {
+        $self->{'priority'} = $priority;
+    }
+    return $self->{'priority'};
+}
+
 1;
 
 =head1 NAME
@@ -343,6 +356,12 @@ As of June 2016, support is limited to recent releases of Chrome and Opera.
 
 L<https://tools.ietf.org/html/draft-west-first-party-cookies-07>
 
+=item B<7. priority flag>
+
+Allowed settings are C<Low>, C<Medium> and C<High>.
+
+Support is limited to recent releases of Chrome.
+
 =back
 
 =head2 Creating New Cookies
@@ -354,7 +373,8 @@ L<https://tools.ietf.org/html/draft-west-first-party-cookies-07>
                              -domain  =>  '.capricorn.com',
                              -path    =>  '/cgi-bin/database',
                              -secure  =>  1,
-                             -samesite=>  "Lax"
+                             -samesite=>  "Lax",
+                             -priority=>  "High",
 	                    );
 
 Create cookies from scratch with the B<new> method.  The B<-name> and
